/******************************************************************************
*   @file   adf4157.h
*   @brief  Header file of ADF4157 Driver for MicroBlaze processor.
*   @author ATofan (alexandru.tofan@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 788
******************************************************************************/
#ifndef _ADF4157_H_
#define _ADF4157_H_
#ifdef ADF4157_GLOBALS
    #define ADF4157_EXT extern volatile
#else
    #define ADF4157_EXT volatile
#endif

/*****************************************************************************/
/* Include Files                                                             */
/*****************************************************************************/
#include "xil_types.h"
#include "xparameters.h"

/*****************************************************************************/
/* Types Declarations                                                        */
/*****************************************************************************/
typedef union _uCProbeDataUnion
{
    char            chData;
    unsigned char   uchData;
    short           siData;
    unsigned short  usiData;
    int             iData;
    unsigned int    uiData;
    float           fData;
}uCProbeDataUnion;

/*****************************************************************************/
/* ADF4157                                                                   */
/*****************************************************************************/
// FRAC/INT Register R0
// MUXOUT Control
#define ADF4157_MUXOUT_Z		(0x00 << 27)
#define ADF4157_MUXOUT_DVdd		(0x01 << 27)
#define ADF4157_MUXOUT_DGND		(0x02 << 27)
#define ADF4157_MUXOUT_RDIV		(0x03 << 27)
#define ADF4157_MUXOUT_NDIV		(0x04 << 27)
#define ADF4157_MUXOUT_ALOCK	(0x05 << 27)
#define ADF4157_MUXOUT_DLOCK	(0x06 << 27)
#define ADF4157_MUXOUT_SDO		(0x07 << 27)
#define ADF4157_MUXOUT_CLKDIV	(0x0A << 27)
#define ADF4157_MUXOUT_FLS		(0x0C << 27)
#define ADF4157_MUXOUT_RDIV2	(0x0D << 27)
#define ADF4157_MUXOUT_NDIV2	(0x0E << 27)
// 12-Bit Integer Value INT
#define ADF4157_INT_VAL(x)		(x << 15)
// 12-Bit MSB Fractional Value FRAC
#define ADF4157_FRAC_MSB_VAL(x) (x << 3)
// Control bits
#define ADF4157_R0_CTRL			0x00

// LSB FRAC Register R1
// 12-Bit LSB Fractional Value FRAC
#define ADF4157_FRAC_LSB_VAL(x) (x << 15)
// Control bits
#define ADF4157_R1_CTRL			0x01

// R Divider Register R2
// CSR EN
#define ADF4157_CSR_EN(x)		(x << 28)
// Current setting
#define ADF4157_CURR_SET(x)		(x << 24)
// Prescaler
#define ADF4157_PRESCALER(x)	(x << 22)
// R DIV 2
#define ADF4157_RDIV2(x)		(x << 21)
// Reference doubler
#define ADF4157_REF_DBL(x)		(x << 20)
// 5-Bit R Counter
#define ADF4157_R_CNT(x)		(x << 15)
// Control bits
#define ADF4157_R2_CTRL			0x02

// Function Register R3
// SD Reset
#define ADF4157_SIG_DEL_RST(x)	(x << 14)
// Lock detect precision
#define ADF4157_LDP(x)			(x << 7)
// Phase detector polarity
#define ADF4157_PD_POL(x)		(x << 6)
// Power down
#define ADF4157_PD(x)			(x << 5)
// CP Three State
#define ADF4157_CP_Z(x)			(x << 4)
// Counter Reset
#define ADF4157_CNT_RST(x)		(x << 3)
// Control bits
#define ADF4157_R3_CTRL			0x03

// Test Register Map R4
// Negative Bleed Current
#define ADF4157_BLEED(x)		((x << 23) | (x << 24))
// Clock Divide Mode
#define ADF4157_CLK_DIV_MODE(x) (x << 19)
// Clock Divide Value
#define ADF4157_CLK_DIV_VAL(x)	(x << 7)
// Control bits
#define ADF4157_R4_CTRL			0x04

// GPIO
#define GPIO_LE                         (1 << 0)
#define GPIO_CE                         (1 << 2)

/*****************************************************************************/
/* Monitored variables declarations                                          */
/*****************************************************************************/
ADF4157_EXT uCProbeDataUnion ADF4157_Data[38];    //used to store the values for uC-Probe communication

/*****************************************************************************/
/*  Functions Prototypes                                                     */
/*****************************************************************************/
int ADF4157_Init(void);
int ADF4157_Set(volatile int value);
int ADF4157_UpdateParameters(void);
int ADF4157_SetR0(void);
int ADF4157_SetR1(void);
int ADF4157_SetR2(void);
int ADF4157_SetR3(void);
int ADF4157_SetR4(void);

#endif /* _ADF4001_H_ */
